@@ -27,12 +27,14 @@ async def help_text(main, msg, context):
         logger.warning("[PROBABLY BUG] Context text for context in help_text(msg) is not defined.")
         context = "SOMETHING'S WRONG BRUH"
 
-    return f"""```md
-Mcdbot (v. {global_config.final.version})
+    return f"""
+Mcdbot (v{global_config.final.version})
 
+```
 Usage (in the {context}):
 {usage}
+```
 
 Source code: {global_config.final.source}
 Issue tracker: {global_config.final.issues}
-```"""
+"""
